# {{ project_name }} - Growth Analysis

> Generated: {{ generated_at.strftime('%Y-%m-%d %H:%M:%S') }}

## Overview

{% if description %}
{{ description }}
{% else %}
This report summarizes the detected growth opportunities and GTM gaps.
{% endif %}

## Technology Stack

| Category | Technology |
|----------|------------|
| Language | {{ tech_stack.language }} |
{% if tech_stack.framework %}| Framework | {{ tech_stack.framework }} |
{% endif %}{% if tech_stack.database %}| Database | {{ tech_stack.database }} |
{% endif %}{% if tech_stack.auth %}| Authentication | {{ tech_stack.auth }} |
{% endif %}{% if tech_stack.deployment %}| Deployment | {{ tech_stack.deployment }} |
{% endif %}{% if tech_stack.package_manager %}| Package Manager | {{ tech_stack.package_manager }} |
{% endif %}{% if tech_stack.services %}| Services | {{ tech_stack.services | join(', ') }} |
{% endif %}

## Growth Hubs

{% if growth_hubs %}
{% for hub in growth_hubs %}
### {{ hub.feature_name }}

- **File**: `{{ hub.file_path }}`
- **Intent**: {{ hub.detected_intent }}
- **Confidence**: {{ (hub.confidence_score * 100)|round }}%
{% if hub.entry_point %}- **Entry Point**: `{{ hub.entry_point }}`{% endif %}
{% if hub.growth_potential %}
- **Growth Potential**:
{% for potential in hub.growth_potential %}
  - {{ potential }}
{% endfor %}
{% endif %}

{% endfor %}
{% else %}
No growth hubs were identified.
{% endif %}

## GTM Gaps

{% if gtm_gaps %}
| Feature | Description | Priority |
|---------|-------------|----------|
{% for gap in gtm_gaps %}
| {{ gap.feature_name }} | {{ gap.description }} | {{ gap.priority }} |
{% endfor %}
{% else %}
No GTM gaps were identified.
{% endif %}

{% if product_overview or features %}
## Product Insights

{% if product_overview %}
**Tagline**: {{ product_overview.tagline or "Not provided" }}

**Value Proposition**: {{ product_overview.value_proposition or "Not provided" }}

**Target Audience**: {{ product_overview.target_audience or "Not provided" }}
{% endif %}

{% if features %}
### Features

{% for feature in features %}
- **{{ feature.name }}**{% if feature.category %} ({{ feature.category }}){% endif %}: {{ feature.description }}
{% endfor %}
{% endif %}
{% endif %}

---

*This analysis was generated by skene-growth.*
