# {{ template.name }} - Growth Template

{% if template.description %}
{{ template.description }}
{% endif %}

## Template Metadata

- **ID**: {{ template.id }}
- **Context Tag**: {{ template.contextTag }}
{% if template.source %}
- **Source**: {{ template.source.type }} ({{ template.source.path }})
{% endif %}

## Usage Instructions

{% if template.usageInstructions %}
{% for instruction in template.usageInstructions %}
- {{ instruction }}
{% endfor %}
{% else %}
No usage instructions provided.
{% endif %}

## Lifecycle Visuals

| Stage | Icon | Color |
|-------|------|-------|
{% for stage, visual in template.visuals.lifecycleVisuals.items() %}
| {{ stage }} | {{ visual.icon }} | {{ visual.color }} |
{% endfor %}

## Keyword Mappings

{% for stage, mapping in template.keywordMappings.items() %}
### {{ stage }}

{% if mapping.keywords %}
{% for keyword in mapping.keywords %}
- {{ keyword }}
{% endfor %}
{% else %}
No keywords provided.
{% endif %}

{% endfor %}

---

*Growth template generated by skene-growth.*
